==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/BollingerBandWidthIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let BollingerBandWidthIndicatorDescription = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicatorDescription extends StrategyBasedIndicatorDescription {
        constructor() {
            super();
            this.ed = 0;
            this.eb = 0;
        }
        get_type() {
            return "BollingerBandWidthIndicator";
        }
        get period() {
            return this.ed;
        }
        set period(a) {
            this.ed = a;
            this.e("Period");
        }
        get multiplier() {
            return this.eb;
        }
        set multiplier(a) {
            this.eb = a;
            this.e("Multiplier");
        }
    }
    BollingerBandWidthIndicatorDescription.$t = /*@__PURE__*/ markType(BollingerBandWidthIndicatorDescription, 'BollingerBandWidthIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return BollingerBandWidthIndicatorDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/BollingerBandWidthIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let BollingerBandWidthIndicatorDescription = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicatorDescription extends StrategyBasedIndicatorDescription {
        get_type() {
            return "BollingerBandWidthIndicator";
        }
        constructor() {
            super();
            this.gn = 0;
            this.gl = 0;
        }
        get period() {
            return this.gn;
        }
        set period(a) {
            this.gn = a;
            this.g("Period");
        }
        get multiplier() {
            return this.gl;
        }
        set multiplier(a) {
            this.gl = a;
            this.g("Multiplier");
        }
    }
    BollingerBandWidthIndicatorDescription.$t = /*@__PURE__*/ markType(BollingerBandWidthIndicatorDescription, 'BollingerBandWidthIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return BollingerBandWidthIndicatorDescription;
})();
